
package interfazgrafica9;

import javax.swing.DefaultListModel;
import javax.swing.JList;
import javax.swing.JTextField;

public class Componentes {
      
      private JList jList;  
      private DefaultListModel defaultListModel;
      private JTextField jTextfield;
           
    public JList getjList() {
        return jList;
    }

    public void setjList(JList jList) {
        this.jList = jList;
    }

    public DefaultListModel getDefaultListModel() {
        return defaultListModel;
    }

    public void setDefaultListModel(DefaultListModel defaultListModel) {
        this.defaultListModel = defaultListModel;
    }
    
    public JTextField getjTextfield() {
        return jTextfield;
    }

    public void setjTextfield(JTextField jTextfield) {
        this.jTextfield = jTextfield;
    }   
}
